@@ -25,6 +25,7 @@ Boston, MA 02111-1307, USA.
 #include "guake-indicator-dbus.h"
 #include "guake-indicator-notify.h"
 #include "guake-indicator-write-json.h"
+#include "guake3.h"
 
 GtkTreeStore* global_tree_view;
 gboolean is_print_edit_menu_form_opened=FALSE;
@@ -214,10 +215,17 @@ void print_edit_menu_form(GtkAction* action, gpointer user_data)
 	gtk_tree_view_append_column(GTK_TREE_VIEW (widgets.tree_view), column_name);
 
 	// Fetch data from the cfg file
-	if (check_xml_cfg_file_presence())
-		widgets.grouphostlist = read_xml_cfg_file();
+	if (customConfFile)
+	{
+		widgets.grouphostlist = read_xml_cfg_file_from_file(customConfFile);
+	}
 	else
-		widgets.grouphostlist = read_json_cfg_file(NULL);
+	{
+		if (check_xml_cfg_file_presence())
+			widgets.grouphostlist = read_xml_cfg_file();
+		else
+			widgets.grouphostlist = read_json_cfg_file(NULL);
+	}
 
 	reload_model_view(&widgets);
 
@@ -504,7 +512,7 @@ static void remove_edit_menu ( GtkWidget *widget, gpointer user_data)
 
 				// Get the root grouphost
 				guint count = 0;
-				guint root_index=-1;
+				gint root_index=-1;
 				HostGroup* iterator;
 				while ( iterator = g_array_index (dialog->grouphostlist, HostGroup*, count))
 				{
@@ -529,7 +537,7 @@ static void remove_edit_menu ( GtkWidget *widget, gpointer user_data)
 						}
 					}
 						
-					HostGroup* root = (HostGroup*)g_array_index (dialog->grouphostlist, HostGroup*, root_index);
+					HostGroup* root = (HostGroup*)g_array_index (dialog->grouphostlist, HostGroup*, (guint)root_index);
 
 					if (root->hostarray==NULL) root->hostarray=dialog->selected_hostgroup->hostarray;
 					else
@@ -1366,7 +1374,8 @@ void write_and_reload(EditMenuDialog* dialog,const char* msg)
 	error_modal_box (msg);
 	refresh_indicator(dialog->user_data);
 	grouphostlist_free(dialog->grouphostlist);
-	dialog->grouphostlist=read_xml_cfg_file();
+	if (customConfFile) dialog->grouphostlist=read_xml_cfg_file_from_file(customConfFile);
+	else dialog->grouphostlist=read_xml_cfg_file();
 	reload_model_view(dialog);
 }
 
@@ -1768,10 +1777,10 @@ void view_popup_menu_onpaste (GtkWidget *menuitem, gpointer userdata)
 		}
 		
 		// Manage the hostgroup copy (not implemented because probably useless)
-		else
+		/*else
 		{
 			
-		}
+		}*/
 	}
 	// Manage the cut and paste
 	else
